
# Type: gene to go term association_subject




URI: [biolink:gene_to_go_term_association_subject](https://w3id.org/biolink/vocab/gene_to_go_term_association_subject)


## Domain and Range

[GeneToGoTermAssociation](GeneToGoTermAssociation.md) ->  <sub>REQ</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [functional association➞subject](functional_association_subject.md)

## Children


## Used by

 * [GeneToGoTermAssociation](GeneToGoTermAssociation.md)
